# Atmoregime

This is a package designed to provide a simple end-to-end workflow for cluster and regime analysis in python.
So far this is a work in progress and is not yet guaranteed to even slightly work.

If you are interested in contributing to or testing this project please contact Josh Dorrington on joshua.dorrington@physics.ox.ac.uk
